@@ -1,5 +1,6 @@
-from styler_rest_framework.pubsub.publishers.messages.send_mail_message\
-    import SendMailMessage
+from styler_rest_framework.pubsub.publishers.messages.send_mail_message import (
+    SendMailMessage,
+)
 from styler_rest_framework.pubsub.publishers import publisher_for_message
 from styler_rest_framework.config import defaults
 
